.. image:: ../../imgs/ooipy_banner2.png
  :width: 700
  :alt: OOIPY Logo
  :align: left

How to Cite OOIPY
=================

Please cite our project as

Schwock, Felix, Ragland, John, Munson, Matthew, & Abadi, Shima. (2020, December 1). OOIPy: A Python toolbox designed to aid in the scientific analysis of Ocean Observatories Initiative (OOI) data (Version v1.0.3). Zenodo. http://doi.org/10.5281/zenodo.4300725

You can also find our project on `Zenedo <https://zenodo.org/record/4276862#.X7QsVNNKhhE>`_ and `GitHub <https://github.com/ooipy/ooipy>`_.